@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -51,8 +51,3 @@ class ConfigExtension(BaseExtension):
         # provide default theme selection
         config.setdefault('tailbone', 'themes', 'default, falafel')
         config.setdefault('tailbone', 'themes.expose_picker', 'true')
-
-
-def expose_vuejs_experiments(config):
-    return config.getbool('tailbone', 'expose_vuejs_experiments',
-                          default=False)
