@@ -2,22 +2,22 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2016 Lance Edgar
+#  Copyright © 2010-2017 Lance Edgar
 #
 #  This file is part of Rattail.
 #
 #  Rattail is free software: you can redistribute it and/or modify it under the
-#  terms of the GNU Affero General Public License as published by the Free
-#  Software Foundation, either version 3 of the License, or (at your option)
-#  any later version.
+#  terms of the GNU General Public License as published by the Free Software
+#  Foundation, either version 3 of the License, or (at your option) any later
+#  version.
 #
 #  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
-#  more details.
+#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+#  details.
 #
-#  You should have received a copy of the GNU Affero General Public License
-#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU General Public License along with
+#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
 """
@@ -35,7 +35,14 @@ from rattail.db import SessionBase
 from rattail.db.continuum import versioning_manager
 
 
-Session = scoped_session(sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False))
+Session = scoped_session(sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False, expire_on_commit=False))
+
+# not necessarily used, but here if you need it
+TempmonSession = scoped_session(sessionmaker())
+TrainwreckSession = scoped_session(sessionmaker())
+
+# empty dict for now, this must populated on app startup (if needed)
+ExtraTrainwreckSessions = {}
 
 
 class TailboneSessionDataManager(datamanager.SessionDataManager):
@@ -120,11 +127,6 @@ def register(session, initial_state=datamanager.STATUS_ACTIVE,
        This function is copied from upstream, and tweaked so that our custom
        :class:`ZopeTransactionExtension` will be used.
     """
-
-    from sqlalchemy import __version__
-    assert tuple(int(x) for x in __version__.split(".")) >= (0, 7), \
-        "SQLAlchemy version 0.7 or greater required to use register()"
-
     from sqlalchemy import event
 
     ext = ZopeTransactionExtension(
@@ -141,8 +143,6 @@ def register(session, initial_state=datamanager.STATUS_ACTIVE,
     event.listen(session, "before_commit", ext.before_commit)
 
 
-# TODO: We can probably assume a new SA version since we use Continuum now.
-if tuple(int(x) for x in sa.__version__.split('.')) >= (0, 7):
-    register(Session)
-else:
-    Session.configure(extension=ZopeTransactionExtension())
+register(Session)
+register(TempmonSession)
+register(TrainwreckSession)
