@@ -966,7 +966,9 @@ class Grid(object):
 
         return self.render_complete(template=template, **kwargs)
 
-    def render_buefy_table_element(self, template='/grids/b-table.mako', data_prop='gridData', **kwargs):
+    def render_buefy_table_element(self, template='/grids/b-table.mako',
+                                   data_prop='gridData', empty_labels=False,
+                                   **kwargs):
         """
         This is intended for ad-hoc "small" grids with static data.  Renders
         just a ``<b-table>`` element instead of the typical "full" grid.
@@ -974,6 +976,7 @@ class Grid(object):
         context = dict(kwargs)
         context['grid'] = self
         context['data_prop'] = data_prop
+        context['empty_labels'] = empty_labels
         if 'grid_columns' not in context:
             context['grid_columns'] = self.get_buefy_columns()
 
