@@ -1,23 +1,23 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
 #  Rattail is free software: you can redistribute it and/or modify it under the
-#  terms of the GNU Affero General Public License as published by the Free
-#  Software Foundation, either version 3 of the License, or (at your option)
-#  any later version.
+#  terms of the GNU General Public License as published by the Free Software
+#  Foundation, either version 3 of the License, or (at your option) any later
+#  version.
 #
 #  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
-#  more details.
+#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+#  details.
 #
-#  You should have received a copy of the GNU Affero General Public License
-#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU General Public License along with
+#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
 """
@@ -29,7 +29,6 @@ from __future__ import unicode_literals, absolute_import
 from rattail.db import model
 
 from tailbone.views import MasterView, AutocompleteView
-from tailbone.views.continuum import VersionView, version_defaults
 
 
 class BrandsView(MasterView):
@@ -37,31 +36,29 @@ class BrandsView(MasterView):
     Master view for the Brand class.
     """
     model_class = model.Brand
+    has_versions = True
+
+    grid_columns = [
+        'name',
+        'confirmed',
+    ]
+
+    form_fields = [
+        'name',
+        'confirmed',
+    ]
 
     def configure_grid(self, g):
+        super(BrandsView, self).configure_grid(g)
+
+        # name
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
-        g.default_sortkey = 'name'
-        g.configure(
-            include=[
-                g.name,
-            ],
-            readonly=True)
+        g.set_sort_defaults('name')
+        g.set_link('name')
 
-    def configure_fieldset(self, fs):
-        fs.configure(
-            include=[
-                fs.name,
-            ])
-        return fs
-
-
-class BrandVersionView(VersionView):
-    """
-    View which shows version history for a brand.
-    """
-    parent_class = model.Brand
-    route_model_view = 'brands.view'
+        # confirmed
+        g.set_type('confirmed', 'boolean')
 
 
 class BrandsAutocomplete(AutocompleteView):
@@ -78,4 +75,3 @@ def includeme(config):
                     renderer='json', permission='brands.list')
 
     BrandsView.defaults(config)
-    version_defaults(config, BrandVersionView, 'brand')
