@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -68,6 +68,7 @@ class CustomersView(MasterView):
 
     grid_columns = [
         'id',
+        'number',
         'name',
         'phone',
         'email',
@@ -75,6 +76,7 @@ class CustomersView(MasterView):
 
     form_fields = [
         'id',
+        'number',
         'name',
         'default_phone',
         'default_address',
@@ -90,6 +92,7 @@ class CustomersView(MasterView):
         'active_in_pos_sticky',
         'people',
         'groups',
+        'members',
     ]
 
     mobile_form_fields = [
@@ -248,6 +251,18 @@ class CustomersView(MasterView):
             f.set_renderer('groups', self.render_groups)
             f.set_readonly('groups')
 
+    def configure_form(self, f):
+        super(CustomersView, self).configure_form(f)
+        customer = f.model_instance
+        permission_prefix = self.get_permission_prefix()
+
+        # members
+        if self.creating:
+            f.remove_field('members')
+        else:
+            f.set_renderer('members', self.render_members)
+            f.set_readonly('members')
+
     def template_kwargs_view(self, **kwargs):
         kwargs['show_profiles_helper'] = self.show_profiles_helper
         return kwargs
@@ -261,14 +276,6 @@ class CustomersView(MasterView):
         if query.count():
             raise colander.Invalid(node, "Customer ID must be unique")
 
-    def render_default_email(self, customer, field):
-        if customer.emails:
-            return customer.emails[0].address
-
-    def render_default_phone(self, customer, field):
-        if customer.phones:
-            return customer.phones[0].number
-
     def render_default_address(self, customer, field):
         if customer.addresses:
             return six.text_type(customer.addresses[0])
@@ -342,6 +349,17 @@ class CustomersView(MasterView):
             items.append(HTML.tag('li', tags.link_to(text, url)))
         return HTML.tag('ul', HTML.literal('').join(items))
 
+    def render_members(self, customer, field):
+        members = customer.members
+        if not members:
+            return ""
+        items = []
+        for member in members:
+            text = six.text_type(member)
+            url = self.request.route_url('members.view', uuid=member.uuid)
+            items.append(HTML.tag('li', tags.link_to(text, url)))
+        return HTML.tag('ul', HTML.literal('').join(items))
+
     def get_version_child_classes(self):
         return [
             (model.CustomerPhoneNumber, 'parent_uuid'),
