@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -42,7 +42,6 @@ from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import MasterView
 from tailbone.views.principal import PrincipalMasterView, PermissionsRenderer
-from tailbone.config import expose_vuejs_experiments
 
 
 class UsersView(PrincipalMasterView):
@@ -133,15 +132,43 @@ class UsersView(PrincipalMasterView):
         g.set_link('last_name')
         g.set_link('display_name')
 
-    def template_kwargs_index(self, **kwargs):
-        kwargs['expose_vuejs_experiments'] = expose_vuejs_experiments(self.rattail_config)
-        return kwargs
+    def editable_instance(self, user):
+        """
+        If the given user is "protected" then we only allow edit if current
+        user is "root".  But if the given user is not protected, this simply
+        returns ``True``.
+        """
+        if self.user_is_protected(user):
+            return self.request.is_root
+        return True
 
-    def vue_index(self):
-        if not expose_vuejs_experiments(self.rattail_config):
-            raise self.notfound()
+    def deletable_instance(self, user):
+        """
+        If the given user is "protected" then we only allow delete if current
+        user is "root".  But if the given user is not protected, this simply
+        returns ``True``.
+        """
+        if self.user_is_protected(user):
+            return self.request.is_root
+        return True
 
-        return self.render_to_response('vue_index', {})
+    def user_is_protected(self, user):
+        """
+        This logic will consult the settings, for a list of "protected"
+        usernames, which should require root privileges to edit.  If no setting
+        is found, or the given ``user`` is not represented in the setting, then
+        edit is allowed.
+
+        But if there is a setting, and the ``user`` is represented in it, then
+        this method will return ``True`` only if the "current" app user is
+        "root", otherwise will return ``False``.
+        """
+        if not hasattr(self, 'protected_usernames'):
+            self.protected_usernames = self.rattail_config.getlist(
+                'tailbone', 'protected_usernames')
+        if self.protected_usernames and user.username in self.protected_usernames:
+            return True
+        return False
 
     def unique_username(self, node, value):
         query = self.Session.query(model.User)\
@@ -339,16 +366,6 @@ class UsersView(PrincipalMasterView):
             items.append(HTML.tag('li', c=[tags.link_to(text, url)]))
         return HTML.tag('ul', c=items)
 
-    def editable_instance(self, user):
-        if self.rattail_config.demo():
-            return user.username != 'chuck'
-        return True
-
-    def deletable_instance(self, user):
-        if self.rattail_config.demo():
-            return user.username != 'chuck'
-        return True
-
     def get_row_data(self, user):
         return self.Session.query(model.UserEvent)\
                            .filter(model.UserEvent.user == user)
@@ -408,10 +425,6 @@ class UsersView(PrincipalMasterView):
 
     @classmethod
     def defaults(cls, config):
-
-        # TODO: probably should stop doing this one
-        cls._vue_index_defaults(config)
-
         cls._user_defaults(config)
         cls._principal_defaults(config)
         cls._defaults(config)
@@ -430,22 +443,6 @@ class UsersView(PrincipalMasterView):
         config.add_tailbone_permission(permission_prefix, '{}.edit_roles'.format(permission_prefix),
                                        "Edit the Roles to which a {} belongs".format(model_title))
 
-    @classmethod
-    def _vue_index_defaults(cls, config):
-        """
-        Provide default configuration for the "Vue.js index" view.  This was
-        essentially an experiment and probably should be abandoned.
-        """
-        rattail_config = config.registry.settings.get('rattail_config')
-        route_prefix = cls.get_route_prefix()
-        url_prefix = cls.get_url_prefix()
-        permission_prefix = cls.get_permission_prefix()
-
-        # vue-index
-        config.add_route('{}.vue_index'.format(route_prefix), '{}/vue-index/'.format(url_prefix))
-        config.add_view(cls, attr='vue_index', route_name='{}.vue_index'.format(route_prefix),
-                        permission='{}.list'.format(permission_prefix))
-
 
 class UserEventsView(MasterView):
     """
